@@ -286,6 +286,12 @@ class Plinux:
             self.logger.error(f'Package ({package}) not found on destination server.')
         return False
 
+    def is_security_update_available(self) -> bool:
+        """Verify security update availability. Returns True is available. Otherwise returns False"""
+
+        result = self.run_cmd('apt-get upgrade -s | grep -i security')
+        return result.ok
+
     # FIXME
     def change_hostname(self, name: str):
         cmd = f'{self.__sudo_cmd} -- sh -c "echo {name} > /etc/hostname; hostname -F /etc/hostname"'
@@ -693,6 +699,78 @@ class Plinux:
 
         return self.run_cmd(cmd)
 
+    def get_disk_size(self, path: str, sudo: bool = False) -> int:
+        """Get disk size.
+
+        df /mnt/xfs/ --block-size=1 --output=size | tail -n 1
+
+        :param path: /mnt/xfs/
+        :param sudo:
+        :return: Size in bytes
+        """
+
+        cmd = f'df {path} --block-size=1 --output=size | tail -n 1'
+        result = self.run_cmd(cmd, sudo=sudo).stdout
+        try:
+            return int(result)
+        except TypeError as err:
+            self.logger.exception(f'Path ({path}) not found or something went wrong.')
+            raise err
+
+    def get_directory_size(self, path: str, sudo: bool = False) -> int:
+        """Get directory size
+
+        du --block-size=1 --total /mnt/ssd-cache/ | tail -n 1 | cut -f1
+
+        :param path: /mnt/ssd-cache/
+        :param sudo:
+        :return: Size in bytes
+        """
+
+        cmd = f'du --block-size=1 --total {path} | tail -n 1 | cut -f1'
+        result = self.run_cmd(cmd, sudo=sudo).stdout
+        try:
+            return int(result)
+        except TypeError as err:
+            self.logger.exception(f'Path ({path}) not found or something went wrong.')
+            raise err
+
+    def get_port_listeners_process_id(self, port: int) -> Union[int, list[int]]:
+        """Get processes ids of port listeners
+
+        sudo -S -p '' -- sh -c 'ss -ltpn | grep ":44301\s" | grep -Po "(?<=pid=)(\d*)" | uniq '
+
+        :param port: /mnt/ssd-cache/
+        :param sudo:
+        :return: Size in bytes
+        """
+
+        cmd = f'ss -ltpn | grep ":{port}\s" | grep -Po "(?<=pid=)(\d*)" | uniq'
+        result = self.run_cmd(cmd, sudo=True).stdout
+        try:
+            return int(result)
+        except TypeError as err:
+            self.logger.exception(f'Path ({port}) not found or something went wrong.')
+            raise err
+        except ValueError:
+            return list(map(int, result.splitlines()))
+
+    def get_process_cmdline(self, *process_id: int, sudo: bool = False) -> list:
+        """Get process command line
+
+        ps h -p 507034,507033,507032,507031,507030,507029,507028,507027,507026 -o args
+
+        :param process_id:
+        :param sudo:
+        :return: List of processes
+        """
+
+        ids = ','.join(map(str, process_id))  # convert to str comma separated
+        cmd = f'ps h -p {ids} -o args'
+        result = self.run_cmd(cmd, sudo=sudo).stdout
+
+        return result.splitlines()
+
     def debug_info(self):
         """Show debug log. Logger must be enabled"""
 
@@ -807,3 +885,11 @@ class Plinux:
     count = count_files
     stat = get_file_permissions
     md5 = get_md5
+
+
+class PackageNotFoundError(BaseException):
+    def __init__(self, package: str = None):
+        self.package = package or 'name is not specified by user'
+
+    def __str__(self):
+        return f'Package ({self.package}) not found!'
